package com.inteligr8.alfresco.activiti;

import com.inteligr8.alfresco.activiti.api.AdminApi;
import com.inteligr8.alfresco.activiti.api.AppDefinitionsApi;
import com.inteligr8.alfresco.activiti.api.AppVersionApi;
import com.inteligr8.alfresco.activiti.api.ModelsApi;
import com.inteligr8.alfresco.activiti.api.ProcessInstancesApi;
import com.inteligr8.alfresco.activiti.api.ProfileApi;
import com.inteligr8.alfresco.activiti.api.TasksApi;
import com.inteligr8.rs.AuthorizationFilter;
import com.inteligr8.rs.Client;
import com.inteligr8.rs.ClientConfiguration;

/**
 * This class serves as the base implementation for the JAX-RS API for the APS
 * Public ReST API.
 * 
 * @author brian@inteligr8.com
 */
public abstract class ApsPublicRestApi {
	
	abstract ClientConfiguration getConfig();
	
	abstract Client getClient();
	
	protected final <T> T getApi(Class<T> apiClass) {
		return this.getApi(null, apiClass);
	}

	protected <T> T getApi(AuthorizationFilter authFilter, Class<T> apiClass) {
		return this.getClient().getApi(authFilter, apiClass);
	}
	
	public AdminApi getAdminApi() {
		return this.getApi(AdminApi.class);
	}
	
	public AdminApi getAdminApi(AuthorizationFilter authFilter) {
		return this.getApi(authFilter, AdminApi.class);
	}
	
	public AppDefinitionsApi getAppDefinitionsApi() {
		return this.getApi(AppDefinitionsApi.class);
	}
	
	public AppDefinitionsApi getAppDefinitionsApi(AuthorizationFilter authFilter) {
		return this.getApi(authFilter, AppDefinitionsApi.class);
	}
	
	public AppVersionApi getAppVersionApi() {
		return this.getApi(AppVersionApi.class);
	}
	
	public AppVersionApi getAppVersionApi(AuthorizationFilter authFilter) {
		return this.getApi(authFilter, AppVersionApi.class);
	}
	
	public ModelsApi getModelsApi() {
		return this.getApi(ModelsApi.class);
	}
	
	public ModelsApi getModelsApi(AuthorizationFilter authFilter) {
		return this.getApi(authFilter, ModelsApi.class);
	}
	
	public ProcessInstancesApi getProcessInstancesApi() {
		return this.getApi(ProcessInstancesApi.class);
	}
	
	public ProcessInstancesApi getProcessInstancesApi(AuthorizationFilter authFilter) {
		return this.getApi(authFilter, ProcessInstancesApi.class);
	}
	
	public ProfileApi getProfileApi() {
		return this.getApi(ProfileApi.class);
	}
	
	public ProfileApi getProfileApi(AuthorizationFilter authFilter) {
		return this.getApi(authFilter, ProfileApi.class);
	}
	
	public TasksApi getTasksApi() {
		return this.getApi(TasksApi.class);
	}
	
	public TasksApi getTasksApi(AuthorizationFilter authFilter) {
		return this.getApi(authFilter, TasksApi.class);
	}

}
